==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/serverless-workflow-text-editor/src/editor/ServerlessWorkflowTextEditorFactory.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import {
  Editor,
  EditorFactory,
  EditorInitArgs,
  EditorTheme,
  KogitoEditorEnvelopeContextType,
} from "@kie-tools-core/editor/dist/api";
import { ServerlessWorkflowTextEditorChannelApi } from "../api";
import { ServerlessWorkflowTextEditorView } from "./ServerlessWorkflowTextEditorView";

export class ServerlessWorkflowTextEditorFactory
  implements EditorFactory<Editor, ServerlessWorkflowTextEditorChannelApi>
{
  public async createEditor(
    ctx: KogitoEditorEnvelopeContextType<ServerlessWorkflowTextEditorChannelApi>,
    initArgs: EditorInitArgs
  ) {
    ctx.supportedThemes = [EditorTheme.LIGHT, EditorTheme.DARK];

    return new ServerlessWorkflowTextEditorView(ctx, initArgs);
  }
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/serverless-workflow-text-editor/src/editor/ServerlessWorkflowTextEditorFactory.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import {
  Editor,
  EditorFactory,
  EditorInitArgs,
  EditorTheme,
  KogitoEditorEnvelopeContextType,
} from "@kie-tools-core/editor/dist/api";
import { ServerlessWorkflowTextEditorChannelApi, ServerlessWorkflowTextEditorEnvelopeApi } from "../api";
import { ServerlessWorkflowTextEditorView } from "./ServerlessWorkflowTextEditorView";

export class ServerlessWorkflowTextEditorFactory
  implements EditorFactory<Editor, ServerlessWorkflowTextEditorEnvelopeApi, ServerlessWorkflowTextEditorChannelApi>
{
  public async createEditor(
    ctx: KogitoEditorEnvelopeContextType<
      ServerlessWorkflowTextEditorEnvelopeApi,
      ServerlessWorkflowTextEditorChannelApi
    >,
    initArgs: EditorInitArgs
  ) {
    ctx.supportedThemes = [EditorTheme.LIGHT, EditorTheme.DARK];

    return new ServerlessWorkflowTextEditorView(ctx, initArgs);
  }
}
